Skip to content
KitploitKITPLOIT
OutilsBlog
Log in
Soumettre
OutilsBlog
Soumettre

Outils de Hacking, PenTest et Cybersécurité pour votre Arsenal de Sécurité !

Kitploit est un répertoire d'outils de hacking, de cybersécurité et de pentesting. Découvrez les dernières mises à jour des projets pour trouver des vulnérabilités, analyser des systèmes, automatiser les tests et renforcer votre sécurité.

··Flux·Contact·Confidentialité·© 2026 Kitploit

Répertoire d'outils

Catégories

Voir toutes les catégories
Loading categories
mapcidr — Programme utilitaire pour effectuer plusieurs opérations pour des plages de sous-réseau/CIDR données. | Kitploit
Outils/GitHubGitHub/projectdiscovery/mapcidr
ReconnaissanceCartographie RéseauCollecte d'InformationsUtilitaires et Frameworks
GitHubprojectdiscovery/mapcidr

mapcidr

Programme utilitaire pour effectuer plusieurs opérations pour des plages de sous-réseau/CIDR données.

Voir le dépôt
1.2k11179il y a 1 jourVérifié par Kitploit

Populaires

Voir tout →

Découvrez les outils les plus utilisés par notre communauté.

Explorer tous les outils

Parcourez notre collection d'outils

Voir tous les outils →
Partager
Site web

mapCIDR

Un programme utilitaire pour effectuer plusieurs opérations pour un sous-réseau/plage CIDR donnée.

Fonctionnalités • Installation • Utilisation • Bibliothèque • Rejoindre Discord


mapCIDR est développé pour faciliter la distribution de charge lors d'opérations de scan massif ; il peut être utilisé à la fois comme bibliothèque et comme outil CLI indépendant.

Fonctionnalités

mapCIDR

  • Support d'expansion CIDR (par défaut)
  • Support de découpage CIDR (sbh, sbc)
  • Support d'agrégation CIDR/IP (a, aa)
  • Support de correspondance CIDR/IP (match-ip)
  • Support de filtrage CIDR/IP (filter-ip)
  • Support de tri CIDR/IP (s, sr)
  • Support de comptage d'hôtes CIDR (count)
  • Support de multiples formats IP (ip-format)
  • Support de mélange IP/PORT (si, sp)
  • Support de conversion IPv4/IPv6 (t4, t6)
  • Support d'entrée CIDR STDIN (pipe)

Installation

go install -v github.com/projectdiscovery/mapcidr/cmd/mapcidr@latest

Utilisation

mapcidr -h

Cela affichera l'aide de l'outil. Voici tous les commutateurs pris en charge.

ENTRÉE :
   -cl, -cidr string[]  CIDR/IP/Fichier contenant une liste de CIDR/IP à traiter

TRAITEMENT :
   -sbc int                  Découper les CIDR par nombre de CIDR donné
   -sbh int                  Découper les CIDR par nombre d'HÔTES donné
   -a, -aggregate            Agréger les IP/CIDR en sous-réseau minimum
   -aa, -aggregate-approx    Agréger approximativement les IP/CIDR épars en sous-réseau minimum
   -c, -count                Compter le nombre d'IP dans un CIDR donné
   -t4, -to-ipv4             Convertir les IP au format IPv4
   -t6, -to-ipv6             Convertir les IP au format IPv6
   -ip-format, -if string[]  Formats IP (0,1,2,3,4,5,6,7,8,9,10,11)
   -zpn, -zero-pad-n int     nombre de zéros de remplissage à utiliser (par défaut 3)
   -zpp, -zero-pad-permute   activer les permutations de 0 à zero-pad-n pour chaque octet

FILTRE :
   -f4, -filter-ipv4         Filtrer les IP IPv4 de l'entrée
   -f6, -filter-ipv6         Filtrer les IP IPv6 de l'entrée
   -skip-base                Ignorer les IP de base (se terminant par .0) dans la sortie
   -skip-broadcast           Ignorer les IP de diffusion (se terminant par .255) dans la sortie
   -mi, -match-ip string[]   IP/CIDR/FICHIER contenant une liste d'IP/CIDR à faire correspondre (séparés par des virgules, entrée fichier)
   -fi, -filter-ip string[]  IP/CIDR/FICHIER contenant une liste d'IP/CIDR à filtrer (séparés par des virgules, entrée fichier)

DIVERS :
   -s, -sort                  Trier les IP/CIDR d'entrée par ordre croissant
   -sr, -sort-reverse         Trier les IP/CIDR d'entrée par ordre décroissant
   -si, -shuffle-ip           Mélanger les IP d'entrée dans un ordre aléatoire
   -sp, -shuffle-port string  Mélanger les IP:Port d'entrée dans un ordre aléatoire

MISE À JOUR :
   -up, -update                 mettre à jour mapcidr vers la dernière version
   -duc, -disable-update-check  désactiver la vérification automatique de mise à jour de mapcidr
   
SORTIE :
   -verbose            Mode verbeux
   -o, -output string  Fichier où écrire la sortie
   -silent             Mode silencieux
   -version            Afficher la version du projet

Exécution de mapCIDR

Pour obtenir une liste d'IP pour un CIDR donné, utilisez la commande suivante :

Expansion CIDR

mapcidr -cidr 173.0.84.0/24
                   ____________  ___    
  __ _  ___ ____  / ___/  _/ _ \/ _ \
 /  ' \/ _ '/ _ \/ /___/ // // / , _/   
/_/_/_/\_,_/ .__/\___/___/____/_/|_| v0.5
          /_/                                                     	 

		projectdiscovery.io

[WRN] Use with caution. You are responsible for your actions
[WRN] Developers assume no liability and are not responsible for any misuse or damage.

173.0.84.0
173.0.84.1
173.0.84.2
173.0.84.3
173.0.84.4
173.0.84.5
173.0.84.13
173.0.84.14
173.0.84.15
173.0.84.16

Il est également possible d'obtenir une liste d'IP pour une plage IP donnée, en utilisant la commande suivante :

$ echo "192.168.0.0-192.168.0.5" | mapcidr
192.168.0.0
192.168.0.1
192.168.0.2
192.168.0.3
192.168.0.4
192.168.0.5

Découpage CIDR par nombre de CIDR

Pour découper un CIDR donné ou une liste de CIDR par nombre de CIDR ou découper en plusieurs sous-réseaux plus petits et égaux, utilisez la commande suivante :

mapcidr -cidr 173.0.84.0/24 -sbc 10 -silent
173.0.84.0/27
173.0.84.32/27
173.0.84.64/27
173.0.84.96/27
173.0.84.128/27
173.0.84.160/27
173.0.84.208/28
173.0.84.192/28
173.0.84.240/28
173.0.84.224/28

Découpage CIDR par nombre d'hôtes

Pour découper le CIDR donné en un nombre égal d'hôtes dans chaque CIDR, utilisez la commande suivante :

mapcidr -cidr 173.0.84.0/16 -sbh 20000 -silent
173.0.0.0/18
173.0.64.0/18
173.0.128.0/18
173.0.192.0/18

Note : Il est possible d'obtenir une division parfaite uniquement lorsque le nombre souhaité de tranches ou d'hôtes par sous-réseau est une puissance de deux. Sinon, l'outil tentera de trouver automatiquement la meilleure stratégie de division pour obtenir le résultat souhaité.

Agrégation CIDR/IP

Pour fusionner plusieurs plages CIDR en un bloc de sous-réseau plus petit, utilisez la commande suivante :

$ mapcidr -cl cidrs.txt -aggregate

Pour lister les blocs CIDR pour une liste donnée d'IP, utilisez la commande suivante :

$ mapcidr -il ips.txt -aggregate

Il est également possible d'effectuer des agrégations approximatives pour des groupes d'IP épars (version 4 uniquement). L'intervalle final contiendra des IP contiguës n'appartenant pas à l'entrée :

$ cat ips.txt 

1.1.1.1
1.1.1.16
1.1.1.31
$ cat ips.txt | mapcidr -aggregate-approx

1.1.1.0/27

Pour lister les blocs CIDR pour une plage IP donnée (IPv4 | IPv6), utilisez la commande suivante :

 $ mapcidr  -cl 192.168.0.1-192.168.0.255 -aggregate
 OU
 $ echo 192.168.0.1-192.168.0.255 | mapcidr -aggregate
192.168.0.1/32
192.168.0.2/31
192.168.0.4/30
192.168.0.8/29
192.168.0.16/28
192.168.0.32/27
192.168.0.64/26
192.168.0.128/25

Correspondance / Filtrage d'IP depuis CIDR

Pour faire correspondre des IP depuis la liste donnée de plages CIDR, utilisez la commande suivante :

$ mapcidr -cidr 192.168.1.0/24 -mi 192.168.1.253,192.168.1.252
$ mapcidr -cidr 192.168.1.0/24 -mi ip_list_to_match.txt

Pour filtrer des IP depuis la liste donnée de plages CIDR, utilisez la commande suivante :

Télécharger l’outil